pub struct AbstractInterpreter { /* private fields */ }Expand description
Abstract interpreter for kernel expressions.
Implementations
Sourceimpl AbstractInterpreter
impl AbstractInterpreter
Sourcepub fn new(max_depth: usize) -> Self
pub fn new(max_depth: usize) -> Self
Create a new abstract interpreter with the given maximum depth.
Sourcepub fn analyze_depth(&self, expr_str: &str) -> DepthDomain
pub fn analyze_depth(&self, expr_str: &str) -> DepthDomain
Analyze the nesting depth of a parenthesised expression string.
Sourcepub fn analyze_sign(&self, expr_str: &str) -> SignDomain
pub fn analyze_sign(&self, expr_str: &str) -> SignDomain
Analyze the numeric sign of a simple expression string.
Recognises leading - for negative and plain digits for positive.
Sourcepub fn analyze_size(&self, expr_str: &str) -> SizeDomain
pub fn analyze_size(&self, expr_str: &str) -> SizeDomain
Analyze the approximate size of an expression string.