AnalysisResults

Struct AnalysisResults 

pub struct AnalysisResults { /* private fields */ }
A collection of abstract analysis results for all variables.

Implementations

Source

impl AnalysisResults

pub fn new() -> Self

Create empty results.

pub fn set(&mut self, var: &str, result: IntervalParityProduct)

Record results for a variable.

pub fn get(&self, var: &str) -> Option<IntervalParityProduct>

Look up results for a variable.

pub fn all(&self) -> &[(String, IntervalParityProduct)]

Return all variables and their results.

pub fn len(&self) -> usize

Return the number of analyzed variables.

pub fn is_empty(&self) -> bool

Return whether any results are present.

pub fn proven_non_negative(&self) -> Vec<&str>

Return variables where the interval is proven to be non-negative.

pub fn proven_even(&self) -> Vec<&str>

Return variables proven to be even.