pub struct ArenaCheckpoint {
pub watermark: usize,
}Expand description
A savepoint that can be used to roll back an arena to a prior state.
Fields
watermark: usizeThe watermark position at checkpoint time.
Implementations
Sourceimpl ArenaCheckpoint
impl ArenaCheckpoint
Sourcepub fn create(arena: &LinearArena) -> Self
pub fn create(arena: &LinearArena) -> Self
Creates a checkpoint at the current position in arena.
Sourcepub fn restore(self, arena: &mut LinearArena)
pub fn restore(self, arena: &mut LinearArena)
Rolls back arena to this checkpoint.