ChainedArena

Struct ChainedArena 

pub struct ChainedArena { /* private fields */ }
A chained-block arena that grows by adding new blocks on overflow.

Implementations

Source

impl ChainedArena

pub fn new(block_size: usize) -> Self

Creates a chained arena with the given initial block size.

pub fn alloc(&mut self, bytes: usize, align: usize) -> usize

Allocates bytes bytes with align alignment.

pub fn num_blocks(&self) -> usize

Returns the total number of blocks.

pub fn total_allocated(&self) -> usize

Returns total bytes allocated (excluding padding).