beta_step

Function beta_step 

pub fn beta_step(expr: &Expr) -> Option<Expr>
Perform one step of beta reduction.

If the expression is an application of a lambda to an argument, substitute the argument for the bound variable in the lambda body.