Auto-generated module
🤖 Generated with SplitRS
Functions
- all_
builtin_ names - Get the full list of all builtin names.
- builtin_
count - Count the total number of builtin names.
- builtin_
ctor_ count - Return the number of constructors for a builtin inductive type.
- builtin_
is_ prop - Check whether a builtin type is in Prop.
- builtin_
is_ recursive - Check whether a builtin type is recursive.
- builtin_
universe_ level - Return the universe level of a builtin type (0 = Prop, 1 = Typeâ‚€).
- classify_
builtin - Classify a name into its
BuiltinKind. - core_
builtin_ infos - Return info for all core builtin types.
- init_
builtin_ env - Initialize the environment with built-in types and axioms.
- is_
builtin - Check if a name is a built-in primitive.
- is_
logical_ connective - Check whether a name is a core logical connective.
- is_
nat_ op - Check if a name is a built-in Nat operation.
- is_
primitive_ value - Check whether a name is a primitive value (not a type).
- is_
string_ op - Check if a name is a built-in String operation.
- lean4_
name - Return the Lean 4 equivalent name for a builtin OxiLean name.
- verify_
builtins - Check if all builtin names are registered in an environment.