pub fn check_dependencies_exist(
env: &Environment,
decl: &Declaration,
) -> Vec<Name>Expand description
Check that all dependencies of a declaration exist in the environment.
Returns the names of any missing dependencies.
pub fn check_dependencies_exist(
env: &Environment,
decl: &Declaration,
) -> Vec<Name>Check that all dependencies of a declaration exist in the environment.
Returns the names of any missing dependencies.