CongrArgKind

Enum CongrArgKind 

pub enum CongrArgKind {
    Fixed,
    Eq,
    HEq,
    Cast,
    Subsingle,
}
Kind of congruence argument.

When generating a congruence lemma for f a₁ a₂ ... aₙ, each argument aᵢ falls into one of these categories.

Variants



Fixed

Fixed: this argument is the same on both sides (e.g., type parameters).



Eq

Eq: this argument requires an equality proof aᵢ = bᵢ.



HEq

HEq: this argument requires a heterogeneous equality HEq aᵢ bᵢ.



Cast

Cast: this argument is obtained by casting via a previous equality.



Subsingle

Subsingletonality: this argument is in a subsingleton type (at most one element), so any two values are equal.