Auto-generated module
🤖 Generated with SplitRS
Modules
- name_
gen - Fresh name generation utilities.
Functions
- collect_
fvars - Collect all free variable IDs in an expression.
- count_
fvar - Count the number of occurrences of a free variable in an expression.
- fvar_
occurs - Check whether a free variable occurs in an expression.
- rename_
fvar - Rename a free variable in an expression.