pub struct ContextDiff {
pub added: Vec<Name>,
pub removed: Vec<Name>,
}Expand description
A diff between two contexts.
Fields
added: Vec<Name>Entries present in the new context but not the old.
removed: Vec<Name>Entries present in the old context but not the new.
Implementations