BucketCounter

Struct BucketCounter 

pub struct BucketCounter<const N: usize> { /* private fields */ }
A counter for tracking how many items are in each of N buckets.

Implementations

Source

impl<const N: usize> BucketCounter<N>

pub const fn new() -> Self

Creates a zeroed bucket counter.

pub fn inc(&mut self, i: usize)

Increments bucket i.

pub fn get(&self, i: usize) -> u64

Returns the count for bucket i.

pub fn total(&self) -> u64

Returns the total count across all buckets.

pub fn argmax(&self) -> usize

Returns the index of the bucket with the highest count.