pub struct ConversionChecker { /* private fields */ }Expand description
Conversion checker for definitional equality.
Wraps a Reducer and performs structural comparison after WHNF.
Implementations
Sourceimpl ConversionChecker
impl ConversionChecker
Sourcepub fn with_transparency(mode: TransparencyMode) -> Self
pub fn with_transparency(mode: TransparencyMode) -> Self
Create a conversion checker with a specific transparency mode.
Sourcepub fn set_transparency(&mut self, mode: TransparencyMode)
pub fn set_transparency(&mut self, mode: TransparencyMode)
Set the transparency mode.
Sourcepub fn transparency(&self) -> TransparencyMode
pub fn transparency(&self) -> TransparencyMode
Get the current transparency mode.
Sourcepub fn is_convertible(&mut self, e1: &Expr, e2: &Expr) -> bool
pub fn is_convertible(&mut self, e1: &Expr, e2: &Expr) -> bool
Check if two expressions are convertible (without environment).
Sourcepub fn is_convertible_in_env(
&mut self,
e1: &Expr,
e2: &Expr,
env: &Environment,
) -> bool
pub fn is_convertible_in_env( &mut self, e1: &Expr, e2: &Expr, env: &Environment, ) -> bool
Check if two expressions are convertible (with environment).
Sourcepub fn set_max_steps(&mut self, max: usize)
pub fn set_max_steps(&mut self, max: usize)
Set the maximum number of reduction steps.