ConstantKind

Enum ConstantKind 

pub enum ConstantKind {
    Axiom,
    Definition,
    Theorem,
    Opaque,
    Inductive,
    Constructor,
    Recursor,
    Quotient,
}
The kind of constant declaration.

Variants



Axiom

An axiom declaration.



Definition

A definition declaration.



Theorem

A theorem declaration.



Opaque

An opaque definition.



Inductive

An inductive type declaration.



Constructor

A constructor of an inductive type.



Recursor

A recursor (eliminator) for an inductive type.



Quotient

A quotient type declaration.

Implementations

Source

impl ConstantKind

pub fn as_str(&self) -> &'static str

Return a human-readable name for the kind.

pub fn has_body(&self) -> bool

Whether this kind can have a proof term (body).

pub fn is_inductive_family(&self) -> bool

Whether this kind is a structural element of an inductive type.