pub struct RecursorVal {
pub common: ConstantVal,
pub all: Vec<Name>,
pub num_params: u32,
pub num_indices: u32,
pub num_motives: u32,
pub num_minors: u32,
pub rules: Vec<RecursorRule>,
pub k: bool,
pub is_unsafe: bool,
}Expand description
Recursor (eliminator) declaration value.
Fields
common: ConstantValCommon fields.
all: Vec<Name>All inductive types in mutual declaration.
num_params: u32Number of parameters.
num_indices: u32Number of indices.
num_motives: u32Number of motive arguments.
num_minors: u32Number of minor premises (one per constructor).
rules: Vec<RecursorRule>Reduction rules (one per constructor).
k: boolWhether this supports K-like reduction.
is_unsafe: boolWhether this is unsafe.
Implementations
Sourceimpl RecursorVal
impl RecursorVal
Sourcepub fn get_major_idx(&self) -> u32
pub fn get_major_idx(&self) -> u32
Get the index of the major premise in the recursor’s arguments.
The major premise is the argument being eliminated. Position: nparams + nmotives + nminors + nindices
Sourcepub fn get_first_index_idx(&self) -> u32
pub fn get_first_index_idx(&self) -> u32
Get the total number of arguments before the major premise.
Sourcepub fn get_rule(&self, ctor: &Name) -> Option<&RecursorRule>
pub fn get_rule(&self, ctor: &Name) -> Option<&RecursorRule>
Find the reduction rule for a given constructor.