pub struct BatchDefEqChecker<'env> { /* private fields */ }Expand description
A batch checker that can check multiple pairs efficiently.
Implementations
Sourceimpl<'env> BatchDefEqChecker<'env>
impl<'env> BatchDefEqChecker<'env>
Sourcepub fn new(env: &'env Environment) -> Self
pub fn new(env: &'env Environment) -> Self
Create a new batch checker.
Sourcepub fn check(&mut self, t: &Expr, s: &Expr) -> bool
pub fn check(&mut self, t: &Expr, s: &Expr) -> bool
Check definitional equality for a single pair.
Sourcepub fn check_all(&mut self, pairs: &[(Expr, Expr)]) -> bool
pub fn check_all(&mut self, pairs: &[(Expr, Expr)]) -> bool
Check all pairs in a list; returns true iff all pairs are def-equal.
Sourcepub fn check_any(&mut self, pairs: &[(Expr, Expr)]) -> bool
pub fn check_any(&mut self, pairs: &[(Expr, Expr)]) -> bool
Check any pair in a list; returns true iff at least one pair is def-equal.
Sourcepub fn count_equal(&mut self, pairs: &[(Expr, Expr)]) -> usize
pub fn count_equal(&mut self, pairs: &[(Expr, Expr)]) -> usize
Count how many pairs in the list are definitionally equal.