Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

constants_with_prefix
Return all constants whose names start with prefix.
contains_any
Check if the environment contains any constant from a given set of names.
env_stats
Compute detailed statistics about an environment.
filter_environment
Filter an environment to only include declarations satisfying a predicate.
merge_environments
Merge two environments into one.
missing_names
Return the subset of names that are NOT present in env.
present_names
Return the subset of names that are present in env.