pub fn filter_environment<F>(env: &Environment, predicate: F) -> EnvironmentExpand description
Filter an environment to only include declarations satisfying a predicate.
pub fn filter_environment<F>(env: &Environment, predicate: F) -> EnvironmentFilter an environment to only include declarations satisfying a predicate.