pub struct EnvironmentSnapshot {
pub names: Vec<Name>,
}Expand description
A snapshot of an Environment at a point in time.
Snapshots are useful for implementing undo/redo in interactive mode.
Fields
names: Vec<Name>Names present at snapshot time, in insertion order.
Implementations
Sourceimpl EnvironmentSnapshot
impl EnvironmentSnapshot
Sourcepub fn from_env(env: &Environment) -> Self
pub fn from_env(env: &Environment) -> Self
Create a snapshot from an environment.
Sourcepub fn diff<'a>(&self, new: &'a EnvironmentSnapshot) -> Vec<&'a Name>
pub fn diff<'a>(&self, new: &'a EnvironmentSnapshot) -> Vec<&'a Name>
Return the names added in new that were not in self.