pub fn has_universe_errors(errors: &[KernelError]) -> boolExpand description
Check whether a list of errors contains any universe inconsistencies.
pub fn has_universe_errors(errors: &[KernelError]) -> boolCheck whether a list of errors contains any universe inconsistencies.