pub struct EtaNormInfo {
pub normalized: Expr,
pub contractions: usize,
pub already_normal: bool,
}Expand description
Information about the eta-normal form of an expression.
Fields
normalized: ExprThe eta-normalized expression.
contractions: usizeNumber of eta contractions performed.
already_normal: boolWhether the expression was already in eta-normal form.
Implementations
Sourceimpl EtaNormInfo
impl EtaNormInfo
Sourcepub fn already_normal(expr: Expr) -> Self
pub fn already_normal(expr: Expr) -> Self
Create an info record for an expression that was already normal.
Sourcepub fn contracted(expr: Expr, n: usize) -> Self
pub fn contracted(expr: Expr, n: usize) -> Self
Create an info record for an expression that required contractions.