pub fn export_environment(
env: &Environment,
module_name: String,
) -> ExportedModuleExpand description
Export an environment to a module.
Exports all declarations and constant info entries from the environment.
pub fn export_environment(
env: &Environment,
module_name: String,
) -> ExportedModuleExport an environment to a module.
Exports all declarations and constant info entries from the environment.