pub fn mk_lam_n(binders: &[(BinderInfo, Expr)], body: Expr) -> ExprExpand description
Build a nested Lam abstraction from a list of binders and a body.
pub fn mk_lam_n(binders: &[(BinderInfo, Expr)], body: Expr) -> ExprBuild a nested Lam abstraction from a list of binders and a body.