pub fn constructor_field_counts(ind: &InductiveType) -> Vec<(Name, u32)>Expand description
Given an InductiveType, return the number of fields in each constructor.
pub fn constructor_field_counts(ind: &InductiveType) -> Vec<(Name, u32)>Given an InductiveType, return the number of fields in each constructor.