pub fn is_enum_inductive(ind: &InductiveType) -> boolExpand description
Check whether an inductive type is an enum (all constructors have no fields).
pub fn is_enum_inductive(ind: &InductiveType) -> boolCheck whether an inductive type is an enum (all constructors have no fields).