pub fn is_singleton_inductive(ind: &InductiveType) -> boolExpand description
Check whether an inductive type is a singleton (one constructor, no recursive fields).
pub fn is_singleton_inductive(ind: &InductiveType) -> boolCheck whether an inductive type is a singleton (one constructor, no recursive fields).