pub enum InductiveError {
AlreadyDefined(Name),
UndefinedType(Name),
InvalidConstructorType(Name),
UniverseTooSmall(String),
NonStrictlyPositive(Name),
Other(String),
}Expand description
Errors that can occur when checking an inductive type definition.
Variants
AlreadyDefined(Name)
The type name is already defined.
UndefinedType(Name)
A constructor references a type that is not in scope.
InvalidConstructorType(Name)
A constructor has an invalid type (not a Pi ending in the inductive type).
UniverseTooSmall(String)
The universe level is not large enough.
NonStrictlyPositive(Name)
A non-strictly positive occurrence of the type.
Other(String)
General error.