Level

Enum Level 

pub enum Level {
    Zero,
    Succ(Box<Level>),
    Max(Box<Level>, Box<Level>),
    IMax(Box<Level>, Box<Level>),
    Param(Name),
    MVar(LevelMVarId),
}
A universe level.

Levels form expressions over zero, successor, max, imax, parameters, and metavariables.

Variants



Zero

Level 0 (Prop).



Succ(Box<Level>)

Successor: u + 1.



Max(Box<Level>, Box<Level>)

Maximum of two levels: max(u, v).



IMax(Box<Level>, Box<Level>)

Impredicative maximum: imax(u, v).

Semantics: imax(u, v) = 0 if v = 0, else max(u, v). This ensures Prop -> Prop : Prop (impredicativity).



Param(Name)

Universe parameter (for polymorphism).



MVar(LevelMVarId)

Universe metavariable (for unification).

Implementations

Source

impl Level

pub fn zero() -> Self

Create Zero level.

pub fn succ(l: Level) -> Self

Create a successor level.

pub fn max(l1: Level, l2: Level) -> Self

Create a max level.

pub fn imax(l1: Level, l2: Level) -> Self

Create an imax level.

pub fn param(name: Name) -> Self

Create a parameter level.

pub fn mvar(id: LevelMVarId) -> Self

Create a level metavariable.

pub fn is_zero(&self) -> bool

Check if this is Zero.

pub fn is_param(&self) -> bool

Check if this is a parameter.

pub fn is_mvar(&self) -> bool

Check if this is a metavariable.

pub fn is_succ(&self) -> bool

Check if this is a successor.

pub fn is_max(&self) -> bool

Check if this is a max.

pub fn is_imax(&self) -> bool

Check if this is an imax.

pub fn is_not_zero(&self) -> bool

Check if this level is definitely not zero.

Returns true if we can statically determine this is >= 1.

pub fn has_mvar(&self) -> bool

Check if this level contains any metavariables.

pub fn has_param(&self) -> bool

Check if this level contains any parameters.

pub fn depth(&self) -> usize

Get the depth (nesting) of this level expression.

pub fn from_nat(n: u32) -> Self

Create a numeric level succ^n(zero).

pub fn to_nat(&self) -> Option<u32>

Try to convert to a numeric level.

Returns Some(n) if this is succ^n(zero), None otherwise.