Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

AnnotationTable
A key-value annotation table for arbitrary metadata.
BeforeAfter
A pair of values useful for before/after comparisons.
BiMap
A bidirectional map between two types.
DiagMeta
A key-value store for diagnostic metadata.
EventCounter
A simple event counter with named events.
FrequencyTable
Tracks the frequency of items.
Generation
A generation counter for validity tracking.
IdDispenser
A counter that dispenses monotonically increasing TypedId values.
IntervalSet
A set of non-overlapping integer intervals.
LoopClock
A clock that measures elapsed time in a loop.
MemoSlot
A memoized computation slot that stores a cached value.
NameGenerator
A fresh-name generator.
NameGeneratorExt
Generates fresh unique names.
NameMap
A mapping from Name to V.
NameMapping
A bidirectional mapping between names and numeric IDs.
NamePool
An interning pool for Name strings.
NameResolver
Resolves unqualified names to fully-qualified names given a namespace.
NameSet
A set of Name values.
NameSetExt
A set of names with fast membership testing.
NameTrie
A trie (prefix tree) for efficient name lookups.
NameTrieExt
A trie (prefix tree) for efficient prefix search over names.
QualifiedName
A name with an optional namespace alias.
QualifiedNameExt
A dot-separated qualified name (e.g. Nat.succ).
RingBuffer
A growable ring buffer with fixed maximum capacity.
ScopeStack
A simple stack-based scope tracker.
SeqNum
A sequence number that can be compared for ordering.
SimpleLruCache
A simple LRU cache backed by a linked list + hash map.
Slot
A slot that can hold a value, with lazy initialization.
SparseBitSet
A simple sparse bit set.
StatCache
A counted-access cache that tracks hit and miss statistics.
StringInterner
Interns strings to save memory (each unique string stored once).
Timestamp
A monotonic timestamp in microseconds.
TypedId
A type-safe wrapper around a u32 identifier.
WorkQueue
A FIFO work queue.
WorkStack
A simple LIFO work queue.

Enums

Name
A hierarchical name.