normalize_selective

Function normalize_selective 

pub fn normalize_selective(
    expr: &Expr,
    env: &Environment,
    whitelist: &[Name],
) -> Expr
Normalize only constants in the expression that appear in the given whitelist.

Useful when you want selective unfolding of specific definitions.