Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

AnnotationTable
A key-value annotation table for arbitrary metadata.
BiMap
A bidirectional map between two types.
BoxedPrinter
Implements Wadler/Lindig-style pretty printing using a box model.
ColorScheme
A set of ANSI color codes for syntax-highlighted pretty printing.
DiagMeta
A key-value store for diagnostic metadata.
DocBuilder
A builder for PrettyDoc values with a fluent API.
EscapeHelper
Helpers for string escaping in pretty output.
EventCounter
A simple event counter with named events.
ExprPrinter
Pretty printer for kernel expressions.
FmtWidth
Utilities for computing display widths.
FrequencyTable
Tracks the frequency of items.
IdDispenser
A counter that dispenses monotonically increasing TypedId values.
IntervalSet
A set of non-overlapping integer intervals.
LoopClock
A clock that measures elapsed time in a loop.
MemoSlot
A memoized computation slot that stores a cached value.
PrettyConfig
Configuration for the pretty printer.
PrettyPrinterState
Mutable state threaded through a recursive pretty printer.
PrettyTable
A simple ASCII table formatter.
PrintConfig
Configuration for pretty printing.
SExprPrinter
Prints an expression as an S-expression.
ScopeStack
A simple stack-based scope tracker.
SimpleLruCache
A simple LRU cache backed by a linked list + hash map.
Slot
A slot that can hold a value, with lazy initialization.
SparseBitSet
A simple sparse bit set.
StatCache
A counted-access cache that tracks hit and miss statistics.
StringInterner
Interns strings to save memory (each unique string stored once).
Timestamp
A monotonic timestamp in microseconds.
TokenPrinter
A pretty printer that works with PrettyToken streams.
TypedId
A type-safe wrapper around a u32 identifier.
WorkQueue
A FIFO work queue.
WorkStack
A simple LIFO work queue.

Enums

Doc
An indented document for pretty-printing with line wrapping.
IndentStyle
Describes the indentation style used by the pretty printer.
PrettyDoc
An abstract pretty-print document.
PrettyToken
A stream of pretty-printable tokens.