PrettyDoc

Enum PrettyDoc 

pub enum PrettyDoc {
    Text(String),
    Newline,
    Indent(Box<PrettyDoc>),
    Concat(Box<PrettyDoc>, Box<PrettyDoc>),
    Group(Box<PrettyDoc>),
    Empty,
}
An abstract pretty-print document.

Variants



Text(String)

A literal text string.



Newline

A newline followed by indentation.



Indent(Box<PrettyDoc>)

Increase indentation for nested content.



Concat(Box<PrettyDoc>, Box<PrettyDoc>)

Concatenation of two documents.



Group(Box<PrettyDoc>)

A group: try to fit on one line, break if too long.



Empty

An empty document.

Implementations

Source

impl PrettyDoc

pub fn text(s: impl Into<String>) -> Self

Creates a Text document.

pub fn concat(a: PrettyDoc, b: PrettyDoc) -> Self

Creates a Concat document.

pub fn indent(inner: PrettyDoc) -> Self

Creates an Indent document.

pub fn group(inner: PrettyDoc) -> Self

Creates a Group document.

pub fn render(&self, _width: usize, style: IndentStyle) -> String

Renders the document to a String using the given line width and indent style.