pub struct FmtWidth;Expand description
Utilities for computing display widths.
Implementations
Sourceimpl FmtWidth
impl FmtWidth
Sourcepub fn decimal_width(n: usize) -> usize
pub fn decimal_width(n: usize) -> usize
Returns the display width of a usize in decimal.
Sourcepub fn pad_right(s: &str, width: usize) -> String
pub fn pad_right(s: &str, width: usize) -> String
Pads s on the right with spaces to width total chars.