pub struct MemoSlot<T: Clone> { /* private fields */ }Expand description
A memoized computation slot that stores a cached value.
Implementations
Sourceimpl<T: Clone> MemoSlot<T>
impl<T: Clone> MemoSlot<T>
Sourcepub fn get_or_compute(&mut self, f: impl FnOnce() -> T) -> &T
pub fn get_or_compute(&mut self, f: impl FnOnce() -> T) -> &T
Returns the cached value, computing it with f if absent.
Sourcepub fn invalidate(&mut self)
pub fn invalidate(&mut self)
Invalidates the cached value.