pub struct QuotientNormalizer { /* private fields */ }Expand description
A normalizer that reduces quotient expressions to normal form.
Repeatedly applies quotient reduction rules until no more apply.
Implementations