pub fn with_context<T, F>(ctx: &str, offset: usize, f: F) -> SerialResult<T>Expand description
Wraps a deserialization call with context for better error messages.
pub fn with_context<T, F>(ctx: &str, offset: usize, f: F) -> SerialResult<T>Wraps a deserialization call with context for better error messages.