pub struct CompatibilityChecker { /* private fields */ }Expand description
Checks binary compatibility between two OleanC files.
Implementations
Sourceimpl CompatibilityChecker
impl CompatibilityChecker
Sourcepub fn new(known_versions: Vec<u32>) -> Self
pub fn new(known_versions: Vec<u32>) -> Self
Create a checker that knows about the given versions.
Sourcepub fn is_compatible(&self, version: u32) -> bool
pub fn is_compatible(&self, version: u32) -> bool
Return whether the version is known-compatible.
Sourcepub fn needs_upgrade(&self, old: u32, new: u32) -> bool
pub fn needs_upgrade(&self, old: u32, new: u32) -> bool
Return whether an upgrade is needed from old to new.