DeclKindSet

Struct DeclKindSet 

pub struct DeclKindSet { /* private fields */ }
A compact encoding for small sets of declaration kinds.

Implementations

Source

impl DeclKindSet

pub fn new() -> Self

Create an empty set.

pub fn add(&mut self, tag: u8)

Add a kind tag to the set.

pub fn contains(&self, tag: u8) -> bool

Return whether a tag is in the set.

pub fn mask(&self) -> u8

Return the raw bitmask.

pub fn count(&self) -> u32

Return the number of distinct kinds in the set.

pub fn is_empty(&self) -> bool

Return whether the set is empty.

pub fn write(&self, w: &mut OleanWriter)

Write to a writer.

pub fn read(r: &mut OleanReader<'_>) -> Result<Self, OleanError>

Read from a reader.