Module interner

Module interner 

Global StringInterner singleton and public API (intern / resolve).

Structs

InternedStr
A lightweight, Copy handle to an interned string.
StringInterner
A thread-safe string interning pool.

Functions

intern
Interns s into the global pool and returns an InternedStr handle.
resolve
Resolves handle to its &'static str content using the global pool.
try_resolve
Like resolve but returns None instead of panicking when the handle is out of range.