pub fn try_resolve(handle: InternedStr) -> Option<&'static str>Expand description
Like resolve but returns None instead of panicking when the handle
is out of range.
pub fn try_resolve(handle: InternedStr) -> Option<&'static str>Like resolve but returns None instead of panicking when the handle
is out of range.