StructShape

Enum StructShape 

pub enum StructShape {
    Ctor {
        name: String,
        arity: u32,
    },
    Proj {
        field_index: u32,
    },
    Other,
}
Represents the shape of a structure expression for comparison.

Variants



Ctor

A constructor applied to n arguments.

Fields

name: String
arity: u32


Proj

A projection of field i from an expression.

Fields

field_index: u32


Other

Any other expression shape.

Implementations

Source

impl StructShape

pub fn ctor(name: impl Into<String>, arity: u32) -> Self

Create a constructor shape.

pub fn proj(field_index: u32) -> Self

Create a projection shape.

pub fn is_ctor(&self) -> bool

Return true if this is a constructor.

pub fn is_proj(&self) -> bool

Return true if this is a projection.

pub fn arity(&self) -> Option<u32>

Return arity if this is a constructor, else None.