pub struct FieldBoundsChecker;Expand description
Validates that field access indices are in-bounds for a structure.
Implementations
Sourceimpl FieldBoundsChecker
impl FieldBoundsChecker
Sourcepub fn check(arity: u32, field_index: u32) -> Result<(), String>
pub fn check(arity: u32, field_index: u32) -> Result<(), String>
Check that the field index is within bounds for the given arity.
Sourcepub fn validate_set(
set: &ProjectionRewriteSet,
reg: &StructureRegistry,
) -> Vec<String>
pub fn validate_set( set: &ProjectionRewriteSet, reg: &StructureRegistry, ) -> Vec<String>
Validate all projection rewrites in a set against a registry.