pub struct ShapeEquivalence { /* private fields */ }Expand description
A simple structural equivalence oracle based on shape matching.
Implementations
Sourceimpl ShapeEquivalence
impl ShapeEquivalence
Sourcepub fn new(registry: StructureRegistry) -> Self
pub fn new(registry: StructureRegistry) -> Self
Create an oracle with the given registry.
Sourcepub fn may_be_equal(&self, a: &StructShape, b: &StructShape) -> bool
pub fn may_be_equal(&self, a: &StructShape, b: &StructShape) -> bool
Return whether two struct shapes can possibly be equal.
Sourcepub fn is_expandable(&self, shape: &StructShape) -> bool
pub fn is_expandable(&self, shape: &StructShape) -> bool
Return whether a shape is eta-expandable (is a known structure ctor).