apply_args

Function apply_args 

pub fn apply_args(f: &Expr, args: &[Expr]) -> Expr
Apply a list of arguments to a function expression via beta reduction.

Given f and [a1, a2, ..., an], returns ((...((f a1) a2) ...) an) after instantiating each lambda body with the corresponding argument.