pub struct SimpleDag { /* private fields */ }Expand description
A simple directed acyclic graph.
Implementations
Sourceimpl SimpleDag
impl SimpleDag
Sourcepub fn successors(&self, node: usize) -> &[usize]
pub fn successors(&self, node: usize) -> &[usize]
Returns the successors of node.
Sourcepub fn can_reach(&self, from: usize, to: usize) -> bool
pub fn can_reach(&self, from: usize, to: usize) -> bool
Returns true if from can reach to via DFS.
Sourcepub fn topological_sort(&self) -> Option<Vec<usize>>
pub fn topological_sort(&self) -> Option<Vec<usize>>
Returns the topological order of nodes, or None if a cycle is detected.