pub struct Substitution { /* private fields */ }Expand description
A substitution mapping bound variable levels to replacement expressions.
Allows performing multiple substitutions in a single pass over the expression.
Implementations