Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Constants

MODULE_VERSION
Version tag for this module.

Traits

ModuleMarker
Marker trait for types that can be used in module-specific contexts.

Functions

closest_match
Find the closest match in a list of candidates using Levenshtein distance.
format_name_list
Format a list of names for display in an error message.
has_obvious_nontermination
Guard against infinite descent.
levenshtein_distance
Compute the Levenshtein distance between two string slices.
module_err
Create a module-level error string.
try_structural_certificate
Build a termination certificate for a structurally recursive function.

Type Aliases

ModuleResult
Generic result type for operations in this module.