pub fn methods_of(class: &Name, registry: &TypeClassRegistry) -> Vec<Method>Expand description
Return all methods for a class, or an empty slice if the class is unknown.
pub fn methods_of(class: &Name, registry: &TypeClassRegistry) -> Vec<Method>Return all methods for a class, or an empty slice if the class is unknown.