AbstractInterpreter

Struct AbstractInterpreter 

pub struct AbstractInterpreter { /* private fields */ }
Abstract interpreter for kernel expressions.

Implementations

Source

impl AbstractInterpreter

pub fn new(max_depth: usize) -> Self

Create a new abstract interpreter with the given maximum depth.

pub fn analyze_depth(&self, expr_str: &str) -> DepthDomain

Analyze the nesting depth of a parenthesised expression string.

pub fn analyze_sign(&self, expr_str: &str) -> SignDomain

Analyze the numeric sign of a simple expression string.

Recognises leading - for negative and plain digits for positive.

pub fn analyze_size(&self, expr_str: &str) -> SizeDomain

Analyze the approximate size of an expression string.

pub fn fixed_point<S: Clone + PartialEq, F: Fn(&S) -> S>( &self, init: S, f: F, ) -> S

Compute a fixed point of f starting from init.

Iterates until the value stabilises or a maximum number of steps (1 000) is reached, at which point the last value is returned.