pub struct AnalysisResults { /* private fields */ }Expand description
A collection of abstract analysis results for all variables.
Implementations
Sourceimpl AnalysisResults
impl AnalysisResults
Sourcepub fn set(&mut self, var: &str, result: IntervalParityProduct)
pub fn set(&mut self, var: &str, result: IntervalParityProduct)
Record results for a variable.
Sourcepub fn get(&self, var: &str) -> Option<IntervalParityProduct>
pub fn get(&self, var: &str) -> Option<IntervalParityProduct>
Look up results for a variable.
Sourcepub fn all(&self) -> &[(String, IntervalParityProduct)]
pub fn all(&self) -> &[(String, IntervalParityProduct)]
Return all variables and their results.
Sourcepub fn proven_non_negative(&self) -> Vec<&str>
pub fn proven_non_negative(&self) -> Vec<&str>
Return variables where the interval is proven to be non-negative.
Sourcepub fn proven_even(&self) -> Vec<&str>
pub fn proven_even(&self) -> Vec<&str>
Return variables proven to be even.