pub struct ChainedArena { /* private fields */ }Expand description
A chained-block arena that grows by adding new blocks on overflow.
Implementations
Sourceimpl ChainedArena
impl ChainedArena
Sourcepub fn new(block_size: usize) -> Self
pub fn new(block_size: usize) -> Self
Creates a chained arena with the given initial block size.
Sourcepub fn alloc(&mut self, bytes: usize, align: usize) -> usize
pub fn alloc(&mut self, bytes: usize, align: usize) -> usize
Allocates bytes bytes with align alignment.
Sourcepub fn num_blocks(&self) -> usize
pub fn num_blocks(&self) -> usize
Returns the total number of blocks.
Sourcepub fn total_allocated(&self) -> usize
pub fn total_allocated(&self) -> usize
Returns total bytes allocated (excluding padding).