pub fn declaration_dependencies(decl: &Declaration) -> Vec<Name>Expand description
Collect the names of all constants referenced in a declaration.
This includes references in both the type and the value (if present).
pub fn declaration_dependencies(decl: &Declaration) -> Vec<Name>Collect the names of all constants referenced in a declaration.
This includes references in both the type and the value (if present).