Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Modules

name_gen
Fresh name generation utilities.

Functions

collect_fvars
Collect all free variable IDs in an expression.
count_fvar
Count the number of occurrences of a free variable in an expression.
fvar_occurs
Check whether a free variable occurs in an expression.
rename_fvar
Rename a free variable in an expression.