Auto-generated module
🤖 Generated with SplitRS
Functions
- constants_
with_ prefix - Return all constants whose names start with
prefix. - contains_
any - Check if the environment contains any constant from a given set of names.
- env_
stats - Compute detailed statistics about an environment.
- filter_
environment - Filter an environment to only include declarations satisfying a predicate.
- merge_
environments - Merge two environments into one.
- missing_
names - Return the subset of
namesthat are NOT present inenv. - present_
names - Return the subset of
namesthat are present inenv.