Auto-generated module
🤖 Generated with SplitRS
Structs
- Annotation
Table - A key-value annotation table for arbitrary metadata.
- Before
After - A pair of values useful for before/after comparisons.
- BiMap
- A bidirectional map between two types.
- Diag
Meta - A key-value store for diagnostic metadata.
- Event
Counter - A simple event counter with named events.
- Frequency
Table - Tracks the frequency of items.
- Generation
- A generation counter for validity tracking.
- IdDispenser
- A counter that dispenses monotonically increasing
TypedIdvalues. - Interval
Set - A set of non-overlapping integer intervals.
- Loop
Clock - A clock that measures elapsed time in a loop.
- Memo
Slot - A memoized computation slot that stores a cached value.
- Name
Generator - A fresh-name generator.
- Name
Generator Ext - Generates fresh unique names.
- NameMap
- A mapping from
NametoV. - Name
Mapping - A bidirectional mapping between names and numeric IDs.
- Name
Pool - An interning pool for
Namestrings. - Name
Resolver - Resolves unqualified names to fully-qualified names given a namespace.
- NameSet
- A set of
Namevalues. - Name
SetExt - A set of names with fast membership testing.
- Name
Trie - A trie (prefix tree) for efficient name lookups.
- Name
Trie Ext - A trie (prefix tree) for efficient prefix search over names.
- Qualified
Name - A name with an optional namespace alias.
- Qualified
Name Ext - A dot-separated qualified name (e.g.
Nat.succ). - Ring
Buffer - A growable ring buffer with fixed maximum capacity.
- Scope
Stack - A simple stack-based scope tracker.
- SeqNum
- A sequence number that can be compared for ordering.
- Simple
LruCache - A simple LRU cache backed by a linked list + hash map.
- Slot
- A slot that can hold a value, with lazy initialization.
- Sparse
BitSet - A simple sparse bit set.
- Stat
Cache - A counted-access cache that tracks hit and miss statistics.
- String
Interner - Interns strings to save memory (each unique string stored once).
- Timestamp
- A monotonic timestamp in microseconds.
- TypedId
- A type-safe wrapper around a
u32identifier. - Work
Queue - A FIFO work queue.
- Work
Stack - A simple LIFO work queue.
Enums
- Name
- A hierarchical name.