Auto-generated module
🤖 Generated with SplitRS
Structs
- Annotation
Table - A key-value annotation table for arbitrary metadata.
- BiMap
- A bidirectional map between two types.
- Boxed
Printer - Implements Wadler/Lindig-style pretty printing using a box model.
- Color
Scheme - A set of ANSI color codes for syntax-highlighted pretty printing.
- Diag
Meta - A key-value store for diagnostic metadata.
- DocBuilder
- A builder for
PrettyDocvalues with a fluent API. - Escape
Helper - Helpers for string escaping in pretty output.
- Event
Counter - A simple event counter with named events.
- Expr
Printer - Pretty printer for kernel expressions.
- FmtWidth
- Utilities for computing display widths.
- Frequency
Table - Tracks the frequency of items.
- IdDispenser
- A counter that dispenses monotonically increasing
TypedIdvalues. - Interval
Set - A set of non-overlapping integer intervals.
- Loop
Clock - A clock that measures elapsed time in a loop.
- Memo
Slot - A memoized computation slot that stores a cached value.
- Pretty
Config - Configuration for the pretty printer.
- Pretty
Printer State - Mutable state threaded through a recursive pretty printer.
- Pretty
Table - A simple ASCII table formatter.
- Print
Config - Configuration for pretty printing.
- SExpr
Printer - Prints an expression as an S-expression.
- Scope
Stack - A simple stack-based scope tracker.
- Simple
LruCache - A simple LRU cache backed by a linked list + hash map.
- Slot
- A slot that can hold a value, with lazy initialization.
- Sparse
BitSet - A simple sparse bit set.
- Stat
Cache - A counted-access cache that tracks hit and miss statistics.
- String
Interner - Interns strings to save memory (each unique string stored once).
- Timestamp
- A monotonic timestamp in microseconds.
- Token
Printer - A pretty printer that works with
PrettyTokenstreams. - TypedId
- A type-safe wrapper around a
u32identifier. - Work
Queue - A FIFO work queue.
- Work
Stack - A simple LIFO work queue.
Enums
- Doc
- An indented document for pretty-printing with line wrapping.
- Indent
Style - Describes the indentation style used by the pretty printer.
- Pretty
Doc - An abstract pretty-print document.
- Pretty
Token - A stream of pretty-printable tokens.