pub struct SimpLemmaSet { /* private fields */ }Expand description
A collection of simp lemmas that can be applied in sequence.
Implementations
Sourceimpl SimpLemmaSet
impl SimpLemmaSet
Sourcepub fn apply_once(&self, expr: &Expr) -> (Expr, bool)
pub fn apply_once(&self, expr: &Expr) -> (Expr, bool)
Apply all lemmas in order to an expression (one pass).