ShapeEquivalence

Struct ShapeEquivalence 

pub struct ShapeEquivalence { /* private fields */ }
A simple structural equivalence oracle based on shape matching.

Implementations

Source

impl ShapeEquivalence

pub fn new(registry: StructureRegistry) -> Self

Create an oracle with the given registry.

pub fn may_be_equal(&self, a: &StructShape, b: &StructShape) -> bool

Return whether two struct shapes can possibly be equal.

pub fn is_expandable(&self, shape: &StructShape) -> bool

Return whether a shape is eta-expandable (is a known structure ctor).